'use client';

import { useEffect, useState } from 'react';
import {
  Box,
  Button,
  Input,
  Textarea,
  VStack,
  HStack,
  Text,
  useColorModeValue,
  useToast,
} from '@chakra-ui/react';

interface Comment {
  name: string;
  text: string;
  timestamp: string;
  location?: string;
}

interface CommentSectionProps {
  postId: number;
}

export default function CommentSection({ postId }: CommentSectionProps) {
  const [comments, setComments] = useState<Comment[]>([]);
  const [name, setName] = useState('');
  const [text, setText] = useState('');
  const [location, setLocation] = useState<string>('Fetching location...');

  const toast = useToast();
  const storageKey = `comments-${postId}`; // 🔑 Scoped to each post

  // Fetch user location
  useEffect(() => {
    const fetchLocation = async () => {
      try {
        const res = await fetch('https://ipapi.co/json/');
        const data = await res.json();
        const loc = [data.city, data.region, data.country_name].filter(Boolean).join(', ');
        setLocation(loc || 'Unknown Location');
      } catch (err) {
        setLocation('Unknown Location');
      }
    };
    fetchLocation();
  }, []);

  // Load comments for specific post
  useEffect(() => {
    const savedComments = localStorage.getItem(storageKey);
    if (savedComments) {
      setComments(JSON.parse(savedComments));
    }
  }, [storageKey]);

  // Save comments when they change
  useEffect(() => {
    localStorage.setItem(storageKey, JSON.stringify(comments));
  }, [comments, storageKey]);

  const handleAddComment = () => {
    if (!name.trim() || !text.trim()) return;

    const newComment: Comment = {
      name: name.trim(),
      text: text.trim(),
      timestamp: new Date().toLocaleString(),
      location,
    };

    setComments(prev => [newComment, ...prev]);
    setName('');
    setText('');

    toast({
      title: 'Comment submitted',
      description: 'Thank you for your feedback!',
      status: 'success',
      duration: 3000,
      isClosable: true,
    });
  };

  const bg = useColorModeValue('gray.100', 'gray.700');
  const cardBg = useColorModeValue('white', 'gray.800');

  return (
    <Box mt={10} p={{ base: 4, md: 6 }} borderRadius="md" bg={bg}>
      <Text fontSize={{ base: 'lg', md: 'xl' }} mb={4} fontWeight="bold">
        Leave a Comment
      </Text>

      <VStack spacing={3} align="stretch">
        <Input
          placeholder="Your name"
          value={name}
          onChange={e => setName(e.target.value)}
        />
        <Textarea
          placeholder="Your comment"
          value={text}
          onChange={e => setText(e.target.value)}
        />
        <Button
          colorScheme="blue"
          onClick={handleAddComment}
          isDisabled={!name.trim() || !text.trim()}
        >
          Submit
        </Button>
      </VStack>

      {comments.length > 0 && (
        <Box mt={8}>
          <Text fontSize={{ base: 'md', md: 'lg' }} mb={4} fontWeight="semibold">
            {comments.length} Comment{comments.length > 1 ? 's' : ''}
          </Text>
          <VStack spacing={4} align="stretch" maxH="500px" overflowY="auto">
            {comments.map((comment, index) => (
              <Box
                key={index}
                p={4}
                borderRadius="md"
                bg={cardBg}
                shadow="sm"
                wordBreak="break-word"
              >
                <HStack justify="space-between" flexWrap="wrap" mb={1}>
                  <Text fontWeight="bold">{comment.name}</Text>
                  <Text fontSize="xs" color="gray.500">
                    {comment.timestamp}
                  </Text>
                </HStack>
                <Text fontSize="sm" mb={2}>{comment.text}</Text>
                {comment.location && (
                  <Text fontSize="xs" color="gray.400">
                    From: {comment.location}
                  </Text>
                )}
              </Box>
            ))}
          </VStack>
        </Box>
      )}
    </Box>
  );
}
